#This script file executes permutation tests for inter-group and intra-group comparisons
#Permuation test results will be displayed upon giving the name of required table/figure in the manuscript 
#(i.e, TableS3/TableS6/TableS8/Figure2/Figure5) as input.

#Results will be displayed upon giving the name of required table/figure as input,
#Give the inputs of figure/table names without space in between. For instance, give the input as TableS3 to obtain Table S2 in the article.

name <- readline("Please input the name of a Figure/Table = ")
#loading essential packages.
#Using coin package to perform permutation tests.
library("gdata")
library("coin")

#Permutation tests for inter-group comparison between biochemical levels of subjects in different groups, at the first visit. 
#-------------------------------------------------------------------------------------------------------------------------------
#Reading data from excel files 
#Control group measurements
#Master_Data_sheet_C <- read.xls("Supporting_Files/Master Data sheet_Control.xlsx")

Master_Data_sheet_C <- read.xls("Supporting_Files/Master_Datasheet_Control.xls")

#D group measurements
#Master_Data_sheet_D <- read.xls("Supporting_Files/Master Data sheet_Diabetic.xlsx")
Master_Data_sheet_D <- read.xls("Supporting_Files/Master_Datasheet_Diabetic.xls")

#DG group measurements
#Master_Data_sheet_DG <- read.xls("Supporting_Files/Master Data sheet_Diabetic_with_GSH.xlsx")
Master_Data_sheet_D <- read.xls("Supporting_Files/Master_Datasheet_Diabetic.xls")


Variable <- c('F Glucose', 'PP Glucose ', 'HbA1c', 'F Insulin','PP Insulin','GSSG','GSH','OHdG','Age','BMI') #variables

if(name =="TableS3") 
{
  P_CvsD=vector()
  P_CvsDG=vector()
  P_DvsDG=vector()
  
  index<-seq(2,23, by=3)
  
  #Comparison between biochemical levels of subjects in different groups at the first visit 
  #---------------------------------------------------------------------------------------
  
  for( i in index){ 
    #Biochemical measurements at the first visit in Control group subjects
    var_c_1<-Master_Data_sheet_C[2:105,i]
    #Biochemical measurements at the first visit in D group subjects
    var_d_1<-Master_Data_sheet_D[2:103,i]
    #Biochemical measurements at the first visit in DG group subjects
    var_dg_1<-Master_Data_sheet_DG[2:105,i]
    
    var_c_1 <- as.numeric(as.character(var_c_1))
    var_d_1 <- as.numeric(as.character(var_d_1))
    var_dg_1 <- as.numeric(as.character(var_dg_1))
    
    #Permutation tests between biochemical concentrations at the alpha visit of Control and D groups.    
    DV1 <- c(var_c_1, var_d_1)
    IV1 <- factor(rep(c("A", "B"), c(length(var_c_1), length(var_d_1))))
    p1<-pvalue(independence_test(DV1 ~ IV1, distribution="exact"))
    P_CvsD=c(P_CvsD,p1)
    
    #Permutation tests between biochemical concentrations at the alpha visit of Control and DG groups.   
    DV2 <- c(var_c_1, var_dg_1)
    IV2 <- factor(rep(c("A", "B"), c(length(var_c_1), length(var_dg_1))))
    p2<-pvalue(independence_test(DV2 ~ IV2, distribution="exact"))
    P_CvsDG=c(P_CvsDG,p2)
    
    #Permutation tests between biochemical concentrations at the alpha visit of D and DG groups. 
    DV3 <- c(var_d_1, var_dg_1)
    IV3 <- factor(rep(c("A", "B"), c(length(var_d_1), length(var_dg_1))))
    p3<-pvalue(independence_test(DV3 ~ IV3, distribution="exact"))
    P_DvsDG=c(P_DvsDG,p3)
  }
  
  #Comparison between age of subjects in different groups at the first visit
  #--------------------------------------------------------------------------
  
  #Age of subjects in control group
  Age_C=Master_Data_sheet_C[2:105,26]
  
  #Age of subjects in D group
  Age_D=Master_Data_sheet_D[2:103,26]
  
  #Age of subjects in DG group
  Age_DG=Master_Data_sheet_DG[2:105,26]
  
  var_c_1 <- as.numeric(as.character(Age_C))
  var_d_1 <- as.numeric(as.character(Age_D))
  var_dg_1 <- as.numeric(as.character(Age_DG))
  
  #Permutation tests between age of subjects in Control and D groups
  DV1 <- c(var_c_1, var_d_1)
  IV1 <- factor(rep(c("A", "B"), c(length(var_c_1), length(var_d_1))))
  p1<-pvalue(independence_test(DV1 ~ IV1, distribution="exact"))
  P_CvsD=c(P_CvsD,p1)
  
  #Permutation tests between age of subjects in Control and DG groups
  DV2 <- c(var_c_1, var_dg_1)
  IV2 <- factor(rep(c("A", "B"), c(length(var_c_1), length(var_dg_1))))
  p2<-pvalue(independence_test(DV2 ~ IV2, distribution="exact"))
  P_CvsDG=c(P_CvsDG,p2)
  
  #Permutation tests between age of subjects in D and DG groups
  DV3 <- c(var_d_1, var_dg_1)
  IV3 <- factor(rep(c("A", "B"), c(length(var_d_1), length(var_dg_1))))
  p3<-pvalue(independence_test(DV3 ~ IV3, distribution="exact"))
  P_DvsDG=c(P_DvsDG,p3)
  
  #Comparison between BMI of subjects in different groups at the first visit
  #-------------------------------------------------------------------------
  
  #BMI of Control group subjects
  BMI_C=Master_Data_sheet_C[2:105,30]
  
  #BMI of D group subjects
  BMI_D=Master_Data_sheet_D[2:103,30]
  
  #BMI of DG group subjects
  BMI_DG=Master_Data_sheet_DG[2:105,30]
  
  var_c_1 <- as.numeric(as.character(BMI_C))
  var_d_1 <- as.numeric(as.character(BMI_D))
  var_dg_1 <- as.numeric(as.character(BMI_DG))
  
  #Permutation tests for intergroup comparisons between BMI of subjects in Control and D groups 
  DV1 <- c(var_c_1, var_d_1)
  IV1 <- factor(rep(c("A", "B"), c(length(var_c_1), length(var_d_1))))
  p1<-pvalue(independence_test(DV1 ~ IV1, distribution="exact"))
  P_CvsD=c(P_CvsD,p1)
  
  #Permutation tests for intergroup comparisons between BMI of subjects in Control and DG groups 
  DV2 <- c(var_c_1, var_dg_1)
  IV2 <- factor(rep(c("A", "B"), c(length(var_c_1), length(var_dg_1))))
  p2<-pvalue(independence_test(DV2 ~ IV2, distribution="exact"))
  P_CvsDG=c(P_CvsDG,p2)
  
  #Permutation tests for intergroup comparisons between BMI of subjects in D and DG groups 
  DV3 <- c(var_d_1, var_dg_1)
  IV3 <- factor(rep(c("A", "B"), c(length(var_d_1), length(var_dg_1))))
  p3<-pvalue(independence_test(DV3 ~ IV3, distribution="exact"))
  P_DvsDG=c(P_DvsDG,p3)
  
  #The outputs of permutation tests are printed on a table
  #The output table consists of first column with variable names, second, third and fourth columns with p-values of Control vs D, Control vs DG, D vs DG comparisons respectively.
  Output_FirstVisit=data.frame(Variable,P_CvsD,P_CvsDG,P_DvsDG)
  print(Output_FirstVisit)
  #-------------------------------------------------------------------------
} else if(name =="TableS4") 
{
  #Permutation tests for intra-group comparison between biochemical levels of subjects in each group, at different visits. 
  #Initializing null vector for p-values
  pval_alpha_vs_beta=vector()
  pval_alpha_vs_gamma=vector()
  
  #variables
  Control_Group_Variables <- c('F Glucose', 'PP Glucose ', 'HbA1c', 'F Insulin','PP Insulin','GSSG','GSH','OHdG')
  
  #-----------------------------------------------------------------------
  #Control group comparisons 
  
  index<-seq(2,23, by=3)
  for( i in index){ 
    #Biochemical measurements at the first visit in Control group subjects
    var_c_1<-Master_Data_sheet_C[2:105,i]
    
    #Biochemical measurements at the second visit in Control group subjects
    var_c_2<-Master_Data_sheet_C[2:105,i+1]
    
    #Biochemical measurements at the third visit in Control group subjects
    var_c_3<-Master_Data_sheet_C[2:105,i+2]
    
    my.dataC1<-data.frame(var_c_1,var_c_2)
    my.dataC1[my.dataC1==""] <- NA
    my.dataC1<-na.omit(my.dataC1)
    
    my.dataC2<-data.frame(var_c_1,var_c_3)
    my.dataC2[my.dataC2==""] <- NA
    my.dataC2<-na.omit(my.dataC2)
    
    my.dataC1$var_c_1 <- as.numeric(as.character(my.dataC1$var_c_1))
    my.dataC1$var_c_2 <- as.numeric(as.character(my.dataC1$var_c_2))
    
    my.dataC2$var_c_1 <- as.numeric(as.character(my.dataC2$var_c_1))
    my.dataC2$var_c_3 <- as.numeric(as.character(my.dataC2$var_c_3))
    
    #Permutation tests for paired samples to compare between the biochemical levels at alpha and beta visits in control group.
    dta1 <- data.frame(y = c(my.dataC1$var_c_1,my.dataC1$var_c_2),  x = gl(2, length(my.dataC1$var_c_1)),block = factor(rep(seq_along(my.dataC1$var_c_1), 2)))
    p1<-pvalue(symmetry_test(y ~ x | block, data = dta1,distribution = "exact", alternative = "two.sided"))
    pval_alpha_vs_beta=c(pval_alpha_vs_beta,p1)
    
    #Permutation tests for paired samples to compare between the biochemical levels at alpha and gamma visits in control group.
    dta2 <- data.frame( y = c(my.dataC2$var_c_1,my.dataC2$var_c_3), x = gl(2, length(my.dataC2$var_c_1)),block = factor(rep(seq_along(my.dataC2$var_c_1), 2)))
    p2<-pvalue(symmetry_test(y ~ x | block, data = dta2,distribution = "exact", alternative = "two.sided"))
    pval_alpha_vs_gamma=c(pval_alpha_vs_gamma,p2)}
  
  Output_Control=data.frame(Control_Group_Variables,pval_alpha_vs_beta,pval_alpha_vs_gamma)
  
  #The outputs of comparison between differnt visits in control group are printed as a table.
  #The first column consists of variable names whereas second and thrid column gives p-values of alpha verus beta visit, and alpha versus gamma visit comparisons.
  
  print(Output_Control)
  
  #------------------------------------------------------------------------
  #D group comparisons 
  
  #Initializing null vector for p-values
  pval_alpha_vs_beta=vector()
  pval_alpha_vs_gamma=vector()
  
  #variables
  D_Group_Variables <- c('F Glucose', 'PP Glucose ', 'HbA1c', 'F Insulin','PP Insulin','GSSG','GSH','OHdG')
  
  index<-seq(2,23, by=3)
  
  for( i in index){ 
    #Biochemical measurements at the first visit in D group subjects
    var_d_1<-Master_Data_sheet_D[2:103,i]
    
    #Biochemical measurements at the second visit in D group subjects
    var_d_2<-Master_Data_sheet_D[2:103,i+1]
    
    #Biochemical measurements at the third visit in D group subjects
    var_d_3<-Master_Data_sheet_D[2:103,i+2]
    
    my.dataD1<-data.frame(var_d_1,var_d_2)
    my.dataD1[my.dataD1==""] <- NA
    my.dataD1<-na.omit(my.dataD1)
    
    my.dataD2<-data.frame(var_d_1,var_d_3)
    my.dataD2[my.dataD2==""] <- NA
    my.dataD2<-na.omit(my.dataD2)
    
    my.dataD1$var_d_1 <- as.numeric(as.character(my.dataD1$var_d_1))
    my.dataD1$var_d_2 <- as.numeric(as.character(my.dataD1$var_d_2))
    
    my.dataD2$var_d_1 <- as.numeric(as.character(my.dataD2$var_d_1))
    my.dataD2$var_d_3 <- as.numeric(as.character(my.dataD2$var_d_3))
    
    #Permutation tests for paired samples to compare between the biochemical levels at alpha and beta visits in D group.    
    dta1 <- data.frame(y = c(my.dataD1$var_d_1,my.dataD1$var_d_2),  x = gl(2, length(my.dataD1$var_d_1)), block = factor(rep(seq_along(my.dataD1$var_d_1), 2)))
    p1<-pvalue(symmetry_test(y ~ x | block, data = dta1,distribution = "exact", alternative = "two.sided"))
    pval_alpha_vs_beta=c(pval_alpha_vs_beta,p1)
    
    #Permutation tests for paired samples to compare between the biochemical levels at alpha and gamma visits in D group.      
    dta2 <- data.frame( y = c(my.dataD2$var_d_1,my.dataD2$var_d_3), x = gl(2, length(my.dataD2$var_d_1)),block = factor(rep(seq_along(my.dataD2$var_d_1), 2)))
    p2<-pvalue(symmetry_test(y ~ x | block, data = dta2,distribution = "exact", alternative = "two.sided"))
    pval_alpha_vs_gamma=c(pval_alpha_vs_gamma,p2)
  }
  
  Output_D=data.frame(D_Group_Variables,pval_alpha_vs_beta,pval_alpha_vs_gamma)
  
  #Outputs of comparison between differnt visits in D group are printed as a table. 
  #The first column consists of variable names, second and third column gives p-value of  alpha versus beta visit, and alpha versus gamma visit comparisons.
  
  print(Output_D)
  
  #---------------------------------------------------------------------
  #DG group comparisons
  
  #Initializing null vector for p-values
  pval_alpha_vs_beta=vector()
  pval_alpha_vs_gamma=vector()
  #variables
  DG_Group_Variables <- c('F Glucose', 'PP Glucose ', 'HbA1c', 'F Insulin','PP Insulin','GSSG','GSH','OHdG')
  
  for( i in index){ 
    #Biochemical measurements at the first visit in DG group subjects
    var_dg_1<-Master_Data_sheet_DG[2:105,i]
    #Biochemical measurements at the second visit in DG group subjects
    var_dg_2<-Master_Data_sheet_DG[2:105,i+1]
    #Biochemical measurements at the third visit in DG group subjects
    var_dg_3<-Master_Data_sheet_DG[2:105,i+2]
    
    my.dataDG1<-data.frame(var_dg_1,var_dg_2)
    my.dataDG1[my.dataDG1==""] <- NA
    my.dataDG1<-na.omit(my.dataDG1)
    
    my.dataDG2<-data.frame(var_dg_1,var_dg_3)
    my.dataDG2[my.dataDG2==""] <- NA
    my.dataDG2<-na.omit(my.dataDG2)
    
    my.dataDG1$var_dg_1 <- as.numeric(as.character(my.dataDG1$var_dg_1))
    my.dataDG1$var_dg_2 <- as.numeric(as.character(my.dataDG1$var_dg_2))
    
    my.dataDG2$var_dg_1 <- as.numeric(as.character(my.dataDG2$var_dg_1))
    my.dataDG2$var_dg_3 <- as.numeric(as.character(my.dataDG2$var_dg_3))
    
    #Permutation tests for paired samples to compare between the biochemical levels at alpha and beta visits in DG group     
    
    dta1 <- data.frame(y = c(my.dataDG1$var_dg_1,my.dataDG1$var_dg_2), x = gl(2, length(my.dataDG1$var_dg_1)),block = factor(rep(seq_along(my.dataDG1$var_dg_1), 2)))
    p1<-pvalue(symmetry_test(y ~ x | block, data = dta1,distribution = "exact", alternative = "two.sided"))
    pval_alpha_vs_beta=c(pval_alpha_vs_beta,p1)
    
    #Permutation tests for paired samples to compare between the biochemical levels at alpha and gamma visits in DG group
    dta2 <- data.frame( y = c(my.dataDG2$var_dg_1,my.dataDG2$var_dg_3), x = gl(2, length(my.dataDG2$var_dg_1)),block = factor(rep(seq_along(my.dataDG2$var_dg_1), 2)))
    p2<-pvalue(symmetry_test(y ~ x | block, data = dta2,distribution = "exact", alternative = "two.sided"))
    pval_alpha_vs_gamma=c(pval_alpha_vs_gamma,p2)
  }
  
  Output_DG=data.frame(DG_Group_Variables,pval_alpha_vs_beta,pval_alpha_vs_gamma)
  
  #The outputs of comparison between different visits in DG group are printed as a table. 
  #The first column consists of variable names whereas the second and third column gives the p-value of alpha verus beta visit, and alpha versus gamma visit comparisons.
  
  print(Output_DG)
  #---------------------------------------------------------------------------------
} else if(name =="Figure2") 
{
  #Permutation tests for inter-group comparison between 6-month biochemical changes in D and DG groups.
  #Initializing a null vector for p-values
  pval=vector()
  Variable <- c('F Glucose', 'PP Glucose ', 'HbA1c', 'F Insulin','PP Insulin','GSSG','GSH','OHdG')
  
  index<-seq(2,23, by=3)
  
  #Comparison between 6-month biochemical changes in D and DG groups
  #----------------------------------------------------------------------
  
  for( i in index){ 
    #Biochemical measurements at the first visit in D group subjects
    var_d_1<-Master_Data_sheet_D[2:103,i]
    #Biochemical measurements at the second visit in D group subjects
    var_d_2<-Master_Data_sheet_D[2:103,i+1]     
    #Biochemical measurements at the third visit in D group subjects
    var_d_3<-Master_Data_sheet_D[2:103,i+2]
    
    #Biochemical measurements at the first visit in DG group subjects
    var_dg_1<-Master_Data_sheet_DG[2:105,i]
    #Biochemical measurements at the second visit in DG group subjects
    var_dg_2<-Master_Data_sheet_DG[2:105,i+1]
    #Biochemical measurements at the third visit in DG group subjects
    var_dg_3<-Master_Data_sheet_DG[2:105,i+2]
    
    my.dataD<-data.frame(var_d_1,var_d_3)
    my.dataDG<-data.frame(var_dg_1,var_dg_3)
    
    my.dataD$var_d_3 <- as.numeric(as.character(my.dataD$var_d_3))
    my.dataD$var_d_1 <- as.numeric(as.character(my.dataD$var_d_1))
    
    my.dataDG$var_dg_3 <- as.numeric(as.character(my.dataDG$var_dg_3))
    my.dataDG$var_dg_1 <- as.numeric(as.character(my.dataDG$var_dg_1))
    
    #calculating 6-month changes in D group subjects
    var_d_ga=my.dataD$var_d_3-my.dataD$var_d_1
    #calculating 6-month changes in DG group subjects
    var_dg_ga=my.dataDG$var_dg_3-my.dataDG$var_dg_1
    
    #Omitting NA entries
    var_d_ga=na.omit(var_d_ga)
    var_dg_ga=na.omit(var_dg_ga)
    
    #Permutation tests between 6-month biochemical changes from alpha to gamma visit in D, and DG groups.
    DV <- c(var_d_ga, var_dg_ga)
    IV <- factor(rep(c("A", "B"), c(length(var_d_ga), length(var_dg_ga))))
    p<-pvalue(independence_test(DV ~ IV, distribution="exact"))
    pval=c(pval,p)
  }
  
  #The outputs of permutation tests are printed as a table.
  #The output table consists of biochemical variables in the first column and corresponding p-values of permutation tests in the second column 
  Output=data.frame(Variable,pval)
  print(Output)
} else if(name =="Figure5") 
{
  #Permutation tests for inter-group comparison between 6-month biochemical changes in elder subjects of D and DG groups.
  p_alpha_beta=vector()
  p_alpha_gamma=vector()
  
  Variable <- c('F Glucose', 'PP Glucose ', 'HbA1c', 'F Insulin','PP Insulin','GSSG','GSH','OHdG')
  pval=vector()
  index<-seq(2,23, by=3)
  
  #Executing permutation tests between 6-month biochemical changes in  D and DG groups
  #---------------------------------------------------------------------------------------
  
  for( i in index){ 
    #Biochemical measurements at the first visit in D group subjects
    var_d_1<-Master_Data_sheet_D[2:103,i]
    #Biochemical measurements at the second visit in D group subjects
    var_d_2<-Master_Data_sheet_D[2:103,i+1]
    #Biochemical measurements at the third visit in D group subjects
    var_d_3<-Master_Data_sheet_D[2:103,i+2]
    
    #Biochemical measurements at the first visit in DG group subjects
    var_dg_1<-Master_Data_sheet_DG[2:105,i]
    #Biochemical measurements at the second visit in DG group subjects
    var_dg_2<-Master_Data_sheet_DG[2:105,i+1]
    #Biochemical measurements at the third visit in DG group subjects
    var_dg_3<-Master_Data_sheet_DG[2:105,i+2]
    
    #Age of subjects in D group
    Age_D=Master_Data_sheet_D[2:103,26]
    
    #Age of subjects in DG group
    Age_DG=Master_Data_sheet_DG[2:105,26]
    
    #Selecting the subjects with age more than 55 years
    ind1<-which(as.numeric(paste(Age_D))>55)
    ind2<-which(as.numeric(paste(Age_DG))>55)
    
    var_d_1<-var_d_1[ind1]
    var_d_2<-var_d_2[ind1]
    var_d_3<-var_d_3[ind1]
    
    var_dg_1<-var_dg_1[ind2]
    var_dg_2<-var_dg_2[ind2]
    var_dg_3<-var_dg_3[ind2]
    
    my.dataD<-data.frame(var_d_1,var_d_3)
    my.dataDG<-data.frame(var_dg_1,var_dg_3)
    
    my.dataD$var_d_3 <- as.numeric(as.character(my.dataD$var_d_3))
    my.dataD$var_d_1 <- as.numeric(as.character(my.dataD$var_d_1))
    
    my.dataDG$var_dg_3 <- as.numeric(as.character(my.dataDG$var_dg_3))
    my.dataDG$var_dg_1 <- as.numeric(as.character(my.dataDG$var_dg_1))
    
    #calculating 6-month biochemical changes in D group subjects
    var_d_ga=my.dataD$var_d_3-my.dataD$var_d_1
    
    #calculating 6-month biochemical changes in DG group subjects
    var_dg_ga=my.dataDG$var_dg_3-my.dataDG$var_dg_1
    
    #Omitting NA entries
    var_d_ga=na.omit(var_d_ga)
    var_dg_ga=na.omit(var_dg_ga)
    
    #Permutation tests for independent samples to compare between the paired biochemical changes from alpha to gamma visit in D and DG groups.
    DV <- c(var_d_ga, var_dg_ga)
    IV <- factor(rep(c("A", "B"), c(length(var_d_ga), length(var_dg_ga))))
    p<-pvalue(independence_test(DV ~ IV, distribution="exact"))
    pval=c(pval,p)
  }
  
  #The outputs of permutation tests are printed on a table.
  #The output table consists of biochemical variables in the first column and corresponding p-values of permutation tests in the second column. 
  Output=data.frame(Variable,pval)
  print(Output)
} else {
  print("NULL")}
end
